@@ -159,6 +159,17 @@ class StoryLocation(BaseModel):
     height: Optional[float]
 
 
+class StorySticker(BaseModel):
+    id: str
+    type: Optional[str] = 'gif'
+    x: float
+    y: float
+    z: Optional[int] = 1000005
+    width: float
+    height: float
+    rotation: Optional[float] = 0.0
+
+
 class StoryBuild(BaseModel):
     mentions: List[StoryMention]
     path: FilePath
@@ -183,6 +194,7 @@ class Story(BaseModel):
     links: List[StoryLink]
     hashtags: List[StoryHashtag]
     locations: List[StoryLocation]
+    stickers: List[StorySticker]
 
 
 class DirectMessage(BaseModel):
